@@ -4,35 +4,46 @@
  *  tmn is an H.263 encoder somewhat based on the Test Model Near-term
  *  (TMN5) in the ITU-T LBC Experts Group.
  *
- *  Copyright (C) 1996  Telenor R&D, Norway
+ *  Copyright (C) 1995, 1996  Telenor R&D, Norway
  *        Karl Olav Lillevold <Karl.Lillevold@nta.no>
+ *  
+ *  Contacts: 
+ *  Karl Olav Lillevold               <Karl.Lillevold@nta.no>, or
+ *  Robert Danielsen                  <Robert.Danielsen@nta.no>
  *
- *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 2 of the License, or
- *  (at your option) any later version.
- *
- *  This program is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU General Public License for more details.
- *
- *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
- *
- *  Karl Olav Lillevold               <Karl.Lillevold@nta.no>
- *  Telenor Research and Development
- *  P.O.Box 83                        tel.:   +47 63 84 84 00
- *  N-2007 Kjeller, Norway            fax.:   +47 63 81 00 76
- *
- *  Robert Danielsen                  e-mail: Robert.Danielsen@nta.no
- *  Telenor Research and Development  www:    http://www.nta.no/brukere/DVC/
+ *  Telenor Research and Development  http://www.nta.no/brukere/DVC/
  *  P.O.Box 83                        tel.:   +47 63 84 84 00
  *  N-2007 Kjeller, Norway            fax.:   +47 63 81 00 76
  *  
  ************************************************************************/
 
+/*
+ * Disclaimer of Warranty
+ *
+ * These software programs are available to the user without any
+ * license fee or royalty on an "as is" basis.  Telenor Research and
+ * Development disclaims any and all warranties, whether express,
+ * implied, or statuary, including any implied warranties or
+ * merchantability or of fitness for a particular purpose.  In no
+ * event shall the copyright-holder be liable for any incidental,
+ * punitive, or consequential damages of any kind whatsoever arising
+ * from the use of these programs.
+ *
+ * This disclaimer of warranty extends to the user of these programs
+ * and user's customers, employees, agents, transferees, successors,
+ * and assigns.
+ *
+ * Telenor Research and Development does not represent or warrant that
+ * the programs furnished hereunder are free of infringement of any
+ * third-party patents.
+ *
+ * Commercial implementations of H.263, including shareware, are
+ * subject to royalty fees to patent holders.  Many of these patents
+ * are general enough such that they are unavoidable regardless of
+ * implementation design.
+ * */
+
+
 #include"sim.h"
 
 FILE *streamfile;
@@ -82,8 +93,7 @@ void main(int argc, char *argv[])
 
   extern int arith_used;
 
-  fprintf (stdout,"\nTMN (H.263) coder version 1.7, Copyright (C) 1995, 1996 Telenor R&D.\n");
-  fprintf (stdout, "TMN comes with ABSOLUTELY NO WARRANTY; This is free software, and \nyou are welcome to redistribute it under certain conditions; \nSee accompanying COPYING file for details.\n\n");
+  fprintf (stdout,"\nTMN (H.263) coder version 2.0, Copyright (C) 1995, 1996 Telenor R&D, Norway\n");
 
   headerlength = DEF_HEADERLENGTH;
 
@@ -852,98 +862,98 @@ int NextTwoPB(PictImage *next2, PictImage *next1, PictImage *prev,
 
 void Help()
 {
-  fprintf(stderr,"Usage:\ttmn [options] -i <filename> [more options]\n");
-  fprintf(stderr,"Options:\n");
-  fprintf(stderr,"\t-i <filename> original sequence [required parameter]\n");
-  fprintf(stderr,"\t-o <filename> reconstructed frames [%s]\n",
+  fprintf(stdout,"Usage:\ttmn [options] -i <filename> [more options]\n");
+  fprintf(stdout,"Options:\n");
+  fprintf(stdout,"\t-i <filename> original sequence [required parameter]\n");
+  fprintf(stdout,"\t-o <filename> reconstructed frames [%s]\n",
           DEF_OUTFILENAME);
-  fprintf(stderr,"\t-B <filename> filename for bitstream [%s]\n",
+  fprintf(stdout,"\t-B <filename> filename for bitstream [%s]\n",
           DEF_STREAMNAME);
-  fprintf(stderr,"\t-a <n> image to start at [%d]\n",
+  fprintf(stdout,"\t-a <n> image to start at [%d]\n",
           DEF_START_FRAME);
-  fprintf(stderr,"\t-b <n> image to stop at [%d]\n",
+  fprintf(stdout,"\t-b <n> image to stop at [%d]\n",
           DEF_STOP_FRAME);
-  fprintf(stderr,"\t-x <n> coding format [%d]\n",DEF_CODING_FORMAT);
-  fprintf(stderr,"\t-q <n> (1..31) quantization parameter QP [%d]\n",
+  fprintf(stdout,"\t-x <n> coding format [%d]\n",DEF_CODING_FORMAT);
+  fprintf(stdout,"\t-q <n> (1..31) quantization parameter QP [%d]\n",
           DEF_INTER_QUANT);
-  fprintf(stderr,"\t-I <n> (1..31) QP for first frame [%d]\n",
+  fprintf(stdout,"\t-I <n> (1..31) QP for first frame [%d]\n",
           DEF_INTRA_QUANT);
-  fprintf(stderr,"\t-r <n> target bitrate in bits/s, default is variable bitrate\n");
-  fprintf(stderr,"\t-S <n> frames to skip between each encoded frame [%d]\n",
+  fprintf(stdout,"\t-r <n> target bitrate in bits/s, default is variable bitrate\n");
+  fprintf(stdout,"\t-S <n> frames to skip between each encoded frame [%d]\n",
           DEF_FRAMESKIP);
-  fprintf(stderr,"\t-D use unrestricted motion vector mode (annex D) [%s]\n",
+  fprintf(stdout,"\t-D use unrestricted motion vector mode (annex D) [%s]\n",
           DEF_UMV_MODE ? "ON" : "OFF");
-  fprintf(stderr,"\t-E use syntax-based arithmetic coding (annex E) [%s]\n",
+  fprintf(stdout,"\t-E use syntax-based arithmetic coding (annex E) [%s]\n",
           DEF_SAC_MODE ? "ON" : "OFF");
-  fprintf(stderr,"\t-F use advanced prediction mode (annex F) [%s]\n",
+  fprintf(stdout,"\t-F use advanced prediction mode (annex F) [%s]\n",
           DEF_ADV_MODE ? "ON" : "OFF");
-  fprintf(stderr,"\t-G use PB-frames (annex G) [%s]\n",
+  fprintf(stdout,"\t-G use PB-frames (annex G) [%s]\n",
           DEF_PBF_MODE ? "ON" : "OFF");
-  fprintf(stderr,"\t-h Prints simple help\n");
-  fprintf(stderr,"\t-H Prints advanced help\n");
-  fprintf(stderr,"\n\tDefault filenames and other options in square brackets \n\tare chosen in config.h\n");
+  fprintf(stdout,"\t-h Prints simple help\n");
+  fprintf(stdout,"\t-H Prints advanced help\n");
+  fprintf(stdout,"\n\tDefault filenames and other options in square brackets \n\tare chosen in config.h\n");
   return;
 }
 
 void AdvancedHelp()
 {
-  fprintf(stderr,"Usage:\ttmn [options] -i <filename> [more options]\n");
-  fprintf(stderr,"Options:\n");
-  fprintf(stderr,"\t-i <filename> original sequence [required parameter]\n");
-  fprintf(stderr,"\t-o <filename> reconstructed frames [%s]\n",
+  fprintf(stdout,"Usage:\ttmn [options] -i <filename> [more options]\n");
+  fprintf(stdout,"Options:\n");
+  fprintf(stdout,"\t-i <filename> original sequence [required parameter]\n");
+  fprintf(stdout,"\t-o <filename> reconstructed frames [%s]\n",
           DEF_OUTFILENAME);
-  fprintf(stderr,"\t-B <filename> filename for bitstream [%s]\n",
+  fprintf(stdout,"\t-B <filename> filename for bitstream [%s]\n",
           DEF_STREAMNAME);
-  fprintf(stderr,"\t-a <n> image to start at [%d]\n",
+  fprintf(stdout,"\t-a <n> image to start at [%d]\n",
           DEF_START_FRAME);
-  fprintf(stderr,"\t-b <n> image to stop at [%d]\n",
+  fprintf(stdout,"\t-b <n> image to stop at [%d]\n",
           DEF_STOP_FRAME);
-  fprintf(stderr,"\t-x <n> coding format [%d]\n",DEF_CODING_FORMAT);
-  fprintf(stderr,"\t       n=1: SQCIF n=2: QCIF n=3: CIF n=4: 4CIF n=5: 16CIF\n");
-  fprintf(stderr,"\t           128x96   176x144  352x288   704x576  1408x1152\n");
-  fprintf(stderr,"\t-s <n> (0..15) integer pel search window [%d]\n",
+  fprintf(stdout,"\t-x <n> coding format [%d]\n",DEF_CODING_FORMAT);
+  fprintf(stdout,"\t       n=1: SQCIF n=2: QCIF n=3: CIF n=4: 4CIF n=5: 16CIF\n");
+  fprintf(stdout,"\t           128x96   176x144  352x288   704x576  1408x1152\n");
+  fprintf(stdout,"\t-s <n> (0..15) integer pel search window [%d]\n",
           DEF_SEEK_DIST);
-  fprintf(stderr,"\t-q <n> (1..31) quantization parameter QP [%d]\n",
+  fprintf(stdout,"\t-q <n> (1..31) quantization parameter QP [%d]\n",
           DEF_INTER_QUANT);
-  fprintf(stderr,"\t-I <n> (1..31) QP for first frame [%d]\n",
+  fprintf(stdout,"\t-I <n> (1..31) QP for first frame [%d]\n",
           DEF_INTRA_QUANT);
-  fprintf(stderr,"\t-r <n> target bitrate in bits/s, default is variable bitrate\n");
+  fprintf(stdout,"\t-r <n> target bitrate in bits/s, default is variable bitrate\n");
 #ifdef OFFLINE_RATE_CONTROL
-  fprintf(stderr,"\t   -R <n> start rate control after n%% of sequence [%d]\n",
+  fprintf(stdout,"\t   -R <n> start rate control after n%% of sequence [%d]\n",
           DEF_START_RATE_CONTROL);
 #else
-  fprintf(stderr,"\t   -R <f> target frame rate [%.2f]\n",
+  fprintf(stdout,"\t   -R <f> target frame rate [%.2f]\n",
           DEF_TARGET_FRAME_RATE);
 #endif
-  fprintf(stderr,"\t-S <n> frames to skip between each encoded frame [%d]\n",
+  fprintf(stdout,"\t-S <n> frames to skip between each encoded frame [%d]\n",
           DEF_FRAMESKIP);
-  fprintf(stderr,"\t-Z <n> reference frame rate (25 or 30 fps) [%.1f]\n",
+  fprintf(stdout,"\t-Z <n> reference frame rate (25 or 30 fps) [%.1f]\n",
           DEF_REF_FRAME_RATE);
-  fprintf(stderr,"\t-O <n> frames skipped in original compared to reference frame rate [%d]\n", DEF_ORIG_SKIP);
-  fprintf(stderr,"\t-e <n> original sequence has n bytes header [%d]\n",
+  fprintf(stdout,"\t-O <n> frames skipped in original compared to reference frame rate [%d]\n", DEF_ORIG_SKIP);
+  fprintf(stdout,"\t-e <n> original sequence has n bytes header [%d]\n",
           DEF_HEADERLENGTH);
-  fprintf(stderr,"\t-g <n> insert sync after each n GOB (slice) [%d]\n",
+  fprintf(stdout,"\t-g <n> insert sync after each n GOB (slice) [%d]\n",
           DEF_INSERT_SYNC);
-  fprintf(stderr,"\t       zero above means no extra syncs inserted\n");
-  fprintf(stderr,"\t-w write difference image to file \"%s\" [%s]\n",
+  fprintf(stdout,"\t       zero above means no extra syncs inserted\n");
+  fprintf(stdout,"\t-w write difference image to file \"%s\" [%s]\n",
           DEF_DIFFILENAME,
           DEF_WRITE_DIFF ? "ON" : "OFF");
-  fprintf(stderr,"\t-m write repeated reconstructed frames to disk [%s]\n",
+  fprintf(stdout,"\t-m write repeated reconstructed frames to disk [%s]\n",
           DEF_WRITE_REPEATED ? "ON" : "OFF");
-  fprintf(stderr,"\t-t write trace to tracefile trace.intra/trace [%s]\n",
+  fprintf(stdout,"\t-t write trace to tracefile trace.intra/trace [%s]\n",
           DEF_WRITE_TRACE ? "ON" : "OFF");
-  fprintf(stderr,"\t-D use unrestricted motion vector mode (annex D) [%s]\n",
+  fprintf(stdout,"\t-D use unrestricted motion vector mode (annex D) [%s]\n",
           DEF_UMV_MODE ? "ON" : "OFF");
-  fprintf(stderr,"\t-E use syntax-based arithmetic coding (annex E) [%s]\n",
+  fprintf(stdout,"\t-E use syntax-based arithmetic coding (annex E) [%s]\n",
           DEF_SAC_MODE ? "ON" : "OFF");
-  fprintf(stderr,"\t-F use advanced prediction mode (annex F) [%s]\n",
+  fprintf(stdout,"\t-F use advanced prediction mode (annex F) [%s]\n",
           DEF_ADV_MODE ? "ON" : "OFF");
-  fprintf(stderr,"\t-G use PB-frames (annex G) [%s]\n",
+  fprintf(stdout,"\t-G use PB-frames (annex G) [%s]\n",
           DEF_PBF_MODE ? "ON" : "OFF");
-  fprintf(stderr,"\t   -Q <n> (0..3) BQUANT parameter [%d]\n",DEF_BQUANT);
-  fprintf(stderr,"\t-h Prints simple help\n");
-  fprintf(stderr,"\t-H Prints advanced help\n");
-  fprintf(stderr,"\n\tDefault filenames and other options in square brackets \n\tare chosen in config.h\n");
+  fprintf(stdout,"\t   -Q <n> (0..3) BQUANT parameter [%d]\n",DEF_BQUANT);
+  fprintf(stdout,"\t-h Prints simple help\n");
+  fprintf(stdout,"\t-H Prints advanced help\n");
+  fprintf(stdout,"\n\tDefault filenames and other options in square brackets \n\tare chosen in config.h\n");
   return;
 }
 
